---
title: Pyqrlew API Documentation
---

# PyQrlew

This page gives an overview of the public PyQrlew objects and utils. Check out the [Qrlew](https://qrlew.readthedocs.io/en/latest/) documentation for a more exhaustive explanation of its capabilities and features.

# API reference

- {doc}`core`
- {doc}`io`

# Examples

- {doc}`examples/dataset_from_queries`
- {doc}`examples/mssql_translator`
- {doc}`examples/postgres_simple_table`
- {doc}`examples/range_propagation`
- {doc}`examples/rewrite_with_dp`


# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`

# Bibliography

```{toctree}
---
maxdepth: 2
hidden:
titlesonly:
---
core
io
```